<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" 
    xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml" 
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    exclude-result-prefixes="xs"
    version="2.0">
    
    
    <xsl:param name="xmlSchema" as="xs:string" select="''"/>
    
    <xsl:variable name="xsdRoot" select="document($xmlSchema)"/>
    
  
    <!-- default matcher -->
    <xsl:template match="/">
        
        <xsl:copy>
            <xsl:apply-templates select="node()"/>
        </xsl:copy>
    </xsl:template>
    

<!--
        Prepend the 'Processing model section
        
        
        <w:p w14:paraId="30EB24B3" w14:textId="4B969FF4" w:rsidR="00AE0702" w:rsidRDefault="65158811" w:rsidP="00A15457">
        <w:pPr>
            <w:pStyle w:val="berschrift1"/>
        </w:pPr>
        <w:r>
            <w:t>Processing Model</w:t>

        
        -->
    
    <xsl:template match="w:p[(w:pPr/w:pStyle/@w:val='berschrift1') and (w:r/w:t/text() = 'Processing Model')]">


        <xsl:for-each select="$xsdRoot/xs:schema/xs:complexType">

            <xsl:call-template name="addComponent"/>
            
        </xsl:for-each>
        
         <xsl:copy>
            <xsl:apply-templates select="@* | node()"/>
        </xsl:copy>
        
    </xsl:template>
    

    <xsl:template name="addComponent">

        <xsl:variable name="genID" select="generate-id(.)"/>
        <xsl:variable name="compName" select="@name"/>

        <!-- 
            #######################################
            component section
            #######################################
         -->
        <w:p w14:paraId="322E42C2" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="berschrift2"/>
            </w:pPr>
            <w:bookmarkStart w:id="129"><xsl:attribute name="w:name" select="concat('_RefComp', $genID)"/></w:bookmarkStart>
            <w:r>
                <w:t>Element <xsl:value-of select="$compName"/></w:t>
            </w:r>
            <w:bookmarkEnd w:id="129"/>
        </w:p>
        <w:p w14:paraId="175AF629" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:spacing w:before="200" w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:cs="Arial"/>
                    <w:b/>
                    <w:bCs/>
                    <w:color w:val="3B006F"/>
                    <w:sz w:val="24"/>
                </w:rPr>
                <w:t>Semantics</w:t>
            </w:r>
        </w:p>
        
        <xsl:if test="xs:annotation/xs:documentation[not(@source)]">
            <w:p w14:paraId="17A239BF" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            
                <xsl:call-template name="printElementContent">
                    <xsl:with-param name="content" select="xs:annotation/xs:documentation[not(@source = 'nonNormative')]"/>
                    <xsl:with-param name="elementName" select="@name"/>
                </xsl:call-template>
            
            </w:p>
        </xsl:if>


        <!-- 
            #######################################
            handle elements
            #######################################
         -->
        <xsl:call-template name="handleComponentElements"/>
        
        
        <xsl:if test="xs:annotation/xs:documentation[@source = 'nonNormative']">
            <w:p w14:paraId="0E7E3AA6" w14:textId="77777777" w:rsidR="00D938DB" w:rsidRDefault="35C1378D" w:rsidP="00D938DB">
                <w:pPr>
                    <w:pStyle w:val="Non-normativeCommentHeading"/>
                </w:pPr>
                <w:r>
                    <w:t>Non-normative Comment:</w:t>
                </w:r>
            </w:p>
            
            <w:p w14:paraId="52BF2CBB" w14:textId="77777777" w:rsidR="006772AC" w:rsidRDefault="006772AC" w:rsidP="006772AC">
                <w:pPr>
                    <w:pStyle w:val="Non-normativeComment"/>
                </w:pPr>
                
                
                <xsl:call-template name="printElementContent">
                    <xsl:with-param name="content" select="xs:annotation/xs:documentation[@source = 'nonNormative']"/>
                    <xsl:with-param name="elementName" select="@name"/>
                </xsl:call-template>
                
            </w:p>
            
        </xsl:if>


        <!-- 
            #######################################
            XML
            #######################################
         -->
        <w:p w14:paraId="0768E3F6" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="berschrift3"/>
            </w:pPr>
            <w:bookmarkStart w:id="130" w:name="_Toc482893916"/>
            <w:r>
                <w:t>XML Syntax</w:t>
            </w:r>
            <w:bookmarkStart w:id="131" w:name="_GoBack"/>
            <w:bookmarkEnd w:id="130"/>
            <w:bookmarkEnd w:id="131"/>
        </w:p>
        <w:p w14:paraId="0E7EDBF3" w14:textId="09865503" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">

            <w:r w:rsidRPr="0CCF9147">
                <w:t xml:space="preserve">The XML element SHALL implement in XML syntax the </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:ascii="Courier New" w:eastAsia="Courier New" w:hAnsi="Courier New" w:cs="Courier New"/>
                </w:rPr>
                <w:t><xsl:value-of select="$compName"/> </w:t>
            </w:r>
            <w:r>
                <w:t xml:space="preserve"> </w:t>
            </w:r>
            <w:r w:rsidRPr="005A6FFD">
                <w:t>component.</w:t>
            </w:r>
        </w:p>
        
        <w:p w14:paraId="3686A38B" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:r w:rsidRPr="005A6FFD">
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial"/>
                </w:rPr>
                <w:t xml:space="preserve">The </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:ascii="Courier New" w:eastAsia="Courier New" w:hAnsi="Courier New" w:cs="Courier New"/>
                </w:rPr>
                <w:t><xsl:value-of select="$compName"/> </w:t>
            </w:r>
            <w:r w:rsidRPr="005A6FFD">
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial"/>
                </w:rPr>
                <w:t xml:space="preserve"> XML element SHALL be defined as in XML Schema file [FILE NAME] whose location is detailed in clause [CLAUSE FOR LINK TO THE XSD], and is copied below for information.</w:t>
            </w:r>
        </w:p>

        <xsl:call-template name="beautifyXMLFragment"/>
            
        <w:p w14:paraId="6505981E" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r>
                <w:t>Each child element of</w:t>
            </w:r>
            <w:r w:rsidRPr="71C71F8C">
                <w:t xml:space="preserve"> </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:ascii="Courier New" w:eastAsia="Courier New" w:hAnsi="Courier New" w:cs="Courier New"/>
                </w:rPr>
                <w:t><xsl:value-of select="$compName"/> </w:t>
            </w:r>
            <w:r w:rsidRPr="71C71F8C">
                <w:t xml:space="preserve"> </w:t>
            </w:r>
            <w:r>
                <w:t xml:space="preserve">XML element SHALL implement in XML syntax the sub-component that has a name equal to its local name.</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="22A998D5" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r>
                <w:t xml:space="preserve">The </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:ascii="Courier New" w:eastAsia="Courier New" w:hAnsi="Courier New" w:cs="Courier New"/>
                </w:rPr>
                <w:t><xsl:value-of select="$compName"/> </w:t>
            </w:r>
            <w:r w:rsidRPr="273734D7">
                <w:t xml:space="preserve"> </w:t>
            </w:r>
            <w:r>
                <w:t>XML element</w:t>
            </w:r>
            <w:r w:rsidRPr="273734D7">
                <w:t xml:space="preserve"> </w:t>
            </w:r>
            <w:r>
                <w:t>SHALL NOT be empty.</w:t>
            </w:r>
        </w:p>
        
        <xsl:if test="xs:annotation/xs:documentation[@source = 'xsdType']">
            
            <w:p w14:paraId="17A239BF" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                
                <xsl:call-template name="printElementContent">
                    <xsl:with-param name="content" select="xs:annotation/xs:documentation[not(@source = 'xsdType')]"/>
                    <xsl:with-param name="elementName" select="@name"/>
                </xsl:call-template>
                
            </w:p>
        </xsl:if>
        
        <!-- 
            #######################################
            JSON
            #######################################
         -->
        
         <w:p w14:paraId="08898D32" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="berschrift3"/>
            </w:pPr>
            <w:bookmarkStart w:id="136" w:name="_Toc482893917"/>
            <w:r>
                <w:t>JSON Syntax</w:t>
            </w:r>
            <w:bookmarkEnd w:id="136"/>
        </w:p>
        <w:p w14:paraId="1FFA5FDA" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                </w:rPr>
                <w:t xml:space="preserve">The </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:ascii="Courier New" w:eastAsia="Courier New" w:hAnsi="Courier New" w:cs="Courier New"/>
                </w:rPr>
                <w:t><xsl:value-of select="$compName"/> </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                </w:rPr>
                <w:t xml:space="preserve"> JSON object SHALL implement in JSON syntax the </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:ascii="Courier New" w:eastAsia="Courier New" w:hAnsi="Courier New" w:cs="Courier New"/>
                </w:rPr>
                <w:t><xsl:value-of select="$compName"/> </w:t>
            </w:r>
            <w:r>
                <w:t xml:space="preserve"> component</w:t>
            </w:r>
            <w:r w:rsidRPr="13173D12">
                <w:t>.</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="0EEDCB63" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                </w:rPr>
                <w:t xml:space="preserve">The </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:ascii="Courier New" w:eastAsia="Courier New" w:hAnsi="Courier New" w:cs="Courier New"/>
                </w:rPr>
                <w:t><xsl:value-of select="$compName"/> </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                </w:rPr>
                <w:t xml:space="preserve"> JSON object SHALL be defined as in JSON Schema file [JSON SCHEMA FILE NAME] whose location is detailed in clause [CLAUSE FOR LINK TO THE JSON SCHEMA FILE], and is copied below for information.</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="48B43574" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r>
                <w:t>"inDocs": {</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="44737C4E" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="273734D7">
                <w:t xml:space="preserve">  </w:t>
            </w:r>
            <w:r w:rsidRPr="7B97890B">
                <w:t>"type": "object",</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="1D749C06" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="273734D7">
                <w:t xml:space="preserve">  </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:t>"id" : "urn:jsonschema:org:oasis:dss:_2_0:core:InputDocuments",</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="0F44F2AE" w14:textId="5F15F587" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="002062A5">
                <w:t xml:space="preserve">  "properties" : {</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="631EC24B" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="002062A5">
                <w:t xml:space="preserve">    "doc" : {"$ref": "#definitions/doc"},</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="2E10A338" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidDel="3866CA22" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="002062A5">
                <w:t xml:space="preserve">    "transformed" : {"$ref": "#definitions/transformed"},</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="4F526B5E" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidDel="3866CA22" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="002062A5">
                <w:t xml:space="preserve">    "docHash" : {"$ref": "#definitions/docHash"},</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="27EDCEB1" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidDel="3866CA22" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="002062A5">
                <w:t xml:space="preserve">  }</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="680632F4" w14:textId="68792E4E" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="002062A5">
                <w:t xml:space="preserve">  "minProperties": 1</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="0F5A08F3" w14:textId="36583C0A" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            <w:r w:rsidRPr="273734D7">
                <w:t>}</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="3328A980" w14:textId="758203A5" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:spacing w:line="259" w:lineRule="auto"/>
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                    <w:highlight w:val="yellow"/>
                </w:rPr>
            </w:pPr>
        </w:p>
        <w:p w14:paraId="2EE0CA21" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:spacing w:line="259" w:lineRule="auto"/>
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                </w:rPr>
            </w:pPr>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                </w:rPr>
                <w:t xml:space="preserve">Each property in the JSON schema above SHALL implement in JSON syntax one sub-component of </w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:ascii="Courier New" w:eastAsia="Courier New" w:hAnsi="Courier New" w:cs="Courier New"/>
                </w:rPr>
                <w:t>InputDocuments</w:t>
            </w:r>
            <w:r w:rsidRPr="002062A5">
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                </w:rPr>
                <w:t xml:space="preserve"> component as shown in the table below.</w:t>
            </w:r>
        </w:p>
        <w:p w14:paraId="0E54B077" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:rPr>
                    <w:rFonts w:eastAsia="Arial" w:cs="Arial"/>
                    <w:sz w:val="22"/>
                    <w:szCs w:val="22"/>
                </w:rPr>
            </w:pPr>
        </w:p>
        <w:tbl>
            <w:tblPr>
                <w:tblStyle w:val="Gitternetztabelle1hell1"/>
                <w:tblW w:w="0" w:type="auto"/>
                <w:tblLook w:val="04A0" w:firstRow="1" w:lastRow="0" w:firstColumn="1" w:lastColumn="0" w:noHBand="0" w:noVBand="1"/>
            </w:tblPr>
            <w:tblGrid>
                <w:gridCol w:w="4675"/>
                <w:gridCol w:w="4675"/>
            </w:tblGrid>
            <w:tr w:rsidR="002062A5" w14:paraId="47C534AC" w14:textId="77777777" w:rsidTr="002062A5">
                <w:trPr>
                    <w:cnfStyle w:val="100000000000" w:firstRow="1" w:lastRow="0" w:firstColumn="0" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                </w:trPr>
                <w:tc>
                    <w:tcPr>
                        <w:cnfStyle w:val="001000000000" w:firstRow="0" w:lastRow="0" w:firstColumn="1" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                        <w:tcW w:w="4675" w:type="dxa"/>
                    </w:tcPr>
                    <w:p w14:paraId="620290FB" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                        <w:pPr>
                            <w:pStyle w:val="Beschriftung"/>
                        </w:pPr>
                        <w:r>
                            <w:t>Component</w:t>
                        </w:r>
                    </w:p>
                </w:tc>
                <w:tc>
                    <w:tcPr>
                        <w:tcW w:w="4675" w:type="dxa"/>
                    </w:tcPr>
                    <w:p w14:paraId="1780EB07" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                        <w:pPr>
                            <w:pStyle w:val="Beschriftung"/>
                            <w:cnfStyle w:val="100000000000" w:firstRow="1" w:lastRow="0" w:firstColumn="0" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                        </w:pPr>
                        <w:r>
                            <w:t>Implementing JSON member name</w:t>
                        </w:r>
                    </w:p>
                </w:tc>
            </w:tr>
            <w:tr w:rsidR="002062A5" w14:paraId="43884972" w14:textId="77777777" w:rsidTr="002062A5">
                <w:tc>
                    <w:tcPr>
                        <w:cnfStyle w:val="001000000000" w:firstRow="0" w:lastRow="0" w:firstColumn="1" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                        <w:tcW w:w="4675" w:type="dxa"/>
                    </w:tcPr>
                    <w:p w14:paraId="73828F1C" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                        <w:pPr>
                            <w:pStyle w:val="Beschriftung"/>
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                                <w:b w:val="0"/>
                                <w:bCs w:val="0"/>
                            </w:rPr>
                        </w:pPr>
                        <w:r w:rsidRPr="002062A5">
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                            <w:t>Document</w:t>
                        </w:r>
                    </w:p>
                </w:tc>
                <w:tc>
                    <w:tcPr>
                        <w:tcW w:w="4675" w:type="dxa"/>
                    </w:tcPr>
                    <w:p w14:paraId="72B92333" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                        <w:pPr>
                            <w:pStyle w:val="Beschriftung"/>
                            <w:cnfStyle w:val="000000000000" w:firstRow="0" w:lastRow="0" w:firstColumn="0" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                        </w:pPr>
                        <w:r w:rsidRPr="002062A5">
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                            <w:t>doc</w:t>
                        </w:r>
                    </w:p>
                </w:tc>
            </w:tr>
            <w:tr w:rsidR="002062A5" w14:paraId="582C16AB" w14:textId="77777777" w:rsidTr="002062A5">
                <w:tc>
                    <w:tcPr>
                        <w:cnfStyle w:val="001000000000" w:firstRow="0" w:lastRow="0" w:firstColumn="1" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                        <w:tcW w:w="4675" w:type="dxa"/>
                    </w:tcPr>
                    <w:p w14:paraId="5E76863C" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                        <w:pPr>
                            <w:pStyle w:val="Beschriftung"/>
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                                <w:b w:val="0"/>
                                <w:bCs w:val="0"/>
                            </w:rPr>
                        </w:pPr>
                        <w:r w:rsidRPr="002062A5">
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                            <w:t>TransformedData</w:t>
                        </w:r>
                    </w:p>
                </w:tc>
                <w:tc>
                    <w:tcPr>
                        <w:tcW w:w="4675" w:type="dxa"/>
                    </w:tcPr>
                    <w:p w14:paraId="04089440" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                        <w:pPr>
                            <w:pStyle w:val="Beschriftung"/>
                            <w:cnfStyle w:val="000000000000" w:firstRow="0" w:lastRow="0" w:firstColumn="0" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                        </w:pPr>
                        <w:r w:rsidRPr="002062A5">
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                            <w:t>transformed</w:t>
                        </w:r>
                    </w:p>
                </w:tc>
            </w:tr>
            <w:tr w:rsidR="002062A5" w14:paraId="33720ABA" w14:textId="77777777" w:rsidTr="002062A5">
                <w:tc>
                    <w:tcPr>
                        <w:cnfStyle w:val="001000000000" w:firstRow="0" w:lastRow="0" w:firstColumn="1" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                        <w:tcW w:w="4675" w:type="dxa"/>
                    </w:tcPr>
                    <w:p w14:paraId="2E6E7989" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                        <w:pPr>
                            <w:pStyle w:val="Beschriftung"/>
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                                <w:b w:val="0"/>
                                <w:bCs w:val="0"/>
                            </w:rPr>
                        </w:pPr>
                        <w:r w:rsidRPr="002062A5">
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                            <w:t>DocumentHash</w:t>
                        </w:r>
                    </w:p>
                </w:tc>
                <w:tc>
                    <w:tcPr>
                        <w:tcW w:w="4675" w:type="dxa"/>
                    </w:tcPr>
                    <w:p w14:paraId="5F394752" w14:textId="77777777" w:rsidR="002062A5" w:rsidRPr="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                        <w:pPr>
                            <w:pStyle w:val="Beschriftung"/>
                            <w:cnfStyle w:val="000000000000" w:firstRow="0" w:lastRow="0" w:firstColumn="0" w:lastColumn="0" w:oddVBand="0" w:evenVBand="0" w:oddHBand="0" w:evenHBand="0" w:firstRowFirstColumn="0" w:firstRowLastColumn="0" w:lastRowFirstColumn="0" w:lastRowLastColumn="0"/>
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                        </w:pPr>
                        <w:r w:rsidRPr="002062A5">
                            <w:rPr>
                                <w:rStyle w:val="Datatype"/>
                            </w:rPr>
                            <w:t>docHash</w:t>
                        </w:r>
                    </w:p>
                </w:tc>
            </w:tr>
        </w:tbl>
        <w:p w14:paraId="391257AA" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5"/>
 
    </xsl:template>

    <!-- 
        #######################################
        handle elements
        #######################################
    -->

    <xsl:template name="handleComponentElements">

        <xsl:variable name="elements">
            <xsl:call-template name="handleComponentAncestorElements"/>
        </xsl:variable>
        
        <xsl:if test="$elements">
            
            <w:p w14:paraId="7493A9F0" w14:textId="11B9DE44" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                <w:r>
                    <w:t>Below follows a list of the sub-components that MAY be present within this component:</w:t>
                </w:r>
            </w:p>
            <xsl:copy-of select="$elements"/>
        </xsl:if>
    </xsl:template>

    <xsl:template name="handleComponentAncestorElements">

        <xsl:variable name="superType" select=".//xs:extension/@base"/>
        <xsl:if test="$superType">

            <xsl:choose>
                <xsl:when test="$superType = 'xs:string'">
                    <xsl:call-template name="handleComponentElement">
                        <xsl:with-param name="name" select="'value'"/>
                        <xsl:with-param name="type" select="'xs:string'"/>
                        <xsl:with-param name="localType" select="'string'"/>
                        <xsl:with-param name="optional" select="false()"/>
                        <xsl:with-param name="doc" select="''"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="$superType = 'xs:base64Binary'">
                    <xsl:call-template name="handleComponentElement">
                        <xsl:with-param name="name" select="'value'"/>
                        <xsl:with-param name="type" select="'xs:base64Binary'"/>
                        <xsl:with-param name="localType" select="'base64Binary'"/>
                        <xsl:with-param name="optional" select="false()"/>
                        <xsl:with-param name="doc" select="''"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="$superType = 'xs:dateTime'">
                    <xsl:call-template name="handleComponentElement">
                        <xsl:with-param name="name" select="'value'"/>
                        <xsl:with-param name="type" select="'xs:dateTime'"/>
                        <xsl:with-param name="localType" select="'dateTime'"/>
                        <xsl:with-param name="optional" select="false()"/>
                        <xsl:with-param name="doc" select="''"/>
                    </xsl:call-template>
                </xsl:when>
                
                <xsl:otherwise>
                    <xsl:variable name="localSuperType" select="substring-after($superType, ':')"/>
                    <xsl:for-each select="//xs:element [@name = $superType] | //xs:element [@name = $localSuperType] | //xs:complexType [@name = $superType] | //xs:complexType [@name = $localSuperType] ">
                        <xsl:call-template name="handleComponentAncestorElements"/>
                    </xsl:for-each>
                    
                </xsl:otherwise>
            </xsl:choose>

        </xsl:if>
        
        <xsl:for-each select=".//xs:element">
            <xsl:call-template name="addComponentElement"/>
        </xsl:for-each>
        <xsl:for-each select=".//xs:attribute">
            <xsl:call-template name="addComponentElement"/>
        </xsl:for-each>
        
    </xsl:template>
    
        
    <xsl:template name="addComponentElement">
        <xsl:param name="refdElement" select="@ref"/>
        
        <xsl:choose>
            <xsl:when test="starts-with($refdElement, 'dss:')">
                <xsl:for-each select="//xs:element [@name = substring-after($refdElement, 'dss:')] | //xs:complexType [@name = substring-after($refdElement, 'dss:')] ">
                    <xsl:call-template name="handleComponentElement"/>
                </xsl:for-each>
            </xsl:when>
            <xsl:when test="string-length($refdElement) &gt; 0">
                <xsl:for-each select="//xs:element [@name = $refdElement] | //xs:complexType [@name = $refdElement] ">
                    <xsl:call-template name="handleComponentElement"/>
                </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="handleComponentElement"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="handleComponentElement">

        <xsl:param name="type" select="@type"/>
        <xsl:param name="name" select="@name"/>
        <xsl:param name="localType" select="substring-after( @type, ':')"/>
        <xsl:param name="sequence" select="..[name(.) = 'sequence']"/>
        <xsl:param name="optional" select="(@use='optional') or (@minOccurs='0')"/>
        <xsl:param name="doc" select="xs:annotation/xs:documentation"/>
        
            
        <w:p w14:paraId="0D47DFD4" w14:textId="18A21D69" w:rsidR="009B32EC" w:rsidRDefault="35C1378D" w:rsidP="009B32EC">
            <w:pPr>
                <w:pStyle w:val="Member"/>
                <w:numPr>
                    <w:ilvl w:val="0"/>
                    <w:numId w:val="2"/>
                </w:numPr>
                <w:spacing w:line="259" w:lineRule="auto"/>
            </w:pPr>
            
            <xsl:variable name="minOcc">
                <xsl:choose>
                    <xsl:when test="@minOccurs"><xsl:value-of select="@minOccurs"/></xsl:when>
                    <xsl:when test="$sequence/@minOccurs"><xsl:value-of select="$sequence/@minOccurs"/></xsl:when>
                    <xsl:otherwise>0</xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <xsl:variable name="maxOcc">
                <xsl:choose>
                    <xsl:when test="@maxOccurs"><xsl:value-of select="@maxOccurs"/></xsl:when>
                    <xsl:when test="$sequence/@maxOccurs"><xsl:value-of select="$sequence/@maxOccurs"/></xsl:when>
                    <xsl:otherwise></xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            
            <xsl:variable name="plainType">
                <xsl:choose>
                    <xsl:when test="$type='xs:string'">a string</xsl:when>
                    <xsl:when test="$type='xs:integer'">an integer</xsl:when>
                    <xsl:when test="$type='xs:language'">a language descriptor</xsl:when>
                    <xsl:when test="$type='xs:anyURI'">an URI</xsl:when>
                    <xsl:when test="$type='xs:base64Binary'">base64 encoded binary data</xsl:when>
                    <xsl:when test="$type='xs:dateTime'">a date/time value</xsl:when>
                    <xsl:when test="$type='xs:boolean'">a boolean</xsl:when>
                    <xsl:when test="$type='xs:ID'">a unique identifier</xsl:when>
                    <xsl:when test="$type='xs:IDREF'">a unique identifier reference</xsl:when>
                    <xsl:when test="$type='xs:IDREFS'">a unique identifier reference</xsl:when>
                    <xsl:when test="//xs:complexType [@name = $localType]">a sub-component </xsl:when>
                    <xsl:otherwise>a sub_component </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <xsl:variable name="plainTypes">
                <xsl:choose>
                    <xsl:when test="$type='xs:string'">strings</xsl:when>
                    <xsl:when test="$type='xs:integer'">integers</xsl:when>
                    <xsl:when test="$type='xs:language'">language descriptors</xsl:when>
                    <xsl:when test="$type='xs:anyURI'">URIs</xsl:when>
                    <xsl:when test="$type='xs:base64Binary'">base64 encoded binary data</xsl:when>
                    <xsl:when test="$type='xs:dateTime'">date/time values</xsl:when>
                    <xsl:when test="$type='xs:boolean'">booleans</xsl:when>
                    <xsl:when test="$type='xs:ID'">unique identifier</xsl:when>
                    <xsl:when test="$type='xs:IDREF'">unique identifier references</xsl:when>
                    <xsl:when test="$type='xs:IDREFS'">unique identifier references</xsl:when>
                    <xsl:when test="//xs:complexType [@name = $localType]">sub-components </xsl:when>
                    <xsl:otherwise>sub_components </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <xsl:variable name="typeCondition">
                <xsl:choose>
                    <xsl:when test="string-length(normalize-space($type))=0"/>
                    <xsl:when test="$type='xs:string'"/>
                    <xsl:when test="$type='xs:integer'"/>
                    <xsl:when test="$type='xs:language'"/>
                    <xsl:when test="$type='xs:anyURI'"/>
                    <xsl:when test="$type='xs:base64Binary'"/>
                    <xsl:when test="$type='xs:dateTime'"/>
                    <xsl:when test="$type='xs:boolean'"/>
                    <xsl:when test="$type='xs:ID'"/>
                    <xsl:when test="$type='xs:IDREF'"/>
                    <xsl:when test="$type='xs:IDREFS'"/>
                    <xsl:otherwise>true</xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <w:r>
                <w:t xml:space="preserve">The <xsl:if test="$optional">optional </xsl:if></w:t>
            </w:r>
            <w:r w:rsidRPr="35C1378D">
                <w:rPr>
                    <w:rStyle w:val="Datatype"/>
                </w:rPr>
                <w:t><xsl:value-of select="$name"/></w:t>
            </w:r>
            <w:r>
                <w:t xml:space="preserve"> element </w:t>
                <xsl:choose>
                    <xsl:when test="$maxOcc = 'unbounded' and $minOcc = 0"><w:t xml:space="preserve">MUST contain zero or more <xsl:copy-of select="$plainTypes"/><xsl:if test="$typeCondition = 'true'">. Each one MUST satisfy the requirements specified in section </xsl:if></w:t></xsl:when>
                    <xsl:when test="$maxOcc = 'unbounded'"><w:t xml:space="preserve">MUST contain <xsl:value-of select="$minOcc"/> or more <xsl:copy-of select="$plainTypes"/><xsl:if test="$typeCondition = 'true'">. Each one MUST satisfy the requirements specified in section </xsl:if></w:t></xsl:when>

                    <xsl:when test="$maxOcc = '1' and $minOcc = 0"><w:t xml:space="preserve">MUST contain <xsl:copy-of select="$plainType"/> if present<xsl:if test="$typeCondition = 'true'">. If present this MUST satisfy the requirements specified in section </xsl:if></w:t></xsl:when>
                    <xsl:when test="$maxOcc = '1'"><w:t xml:space="preserve">MUST contain one <xsl:copy-of select="$plainType"/><xsl:if test="$typeCondition = 'true'">. This MUST satisfy the requirements specified in section </xsl:if></w:t></xsl:when>
                    
                    <xsl:when test="string-length(normalize-space($maxOcc)) &gt; 0 and $minOcc = 0"><w:t xml:space="preserve">MUST contain zero or up to <xsl:value-of select="$maxOcc"/> <xsl:copy-of select="$plainTypes"/><xsl:if test="$typeCondition = 'true'">. Each one MUST satisfy the requirements specified in section </xsl:if></w:t></xsl:when>
                    <xsl:when test="string-length(normalize-space($maxOcc)) &gt; 0"><w:t xml:space="preserve">MUST contain <xsl:value-of select="$minOcc"/> ... <xsl:value-of select="$maxOcc"/> <xsl:copy-of select="$plainTypes"/><xsl:if test="$typeCondition = 'true'">. Each one MUST satisfy the requirements specified in section </xsl:if></w:t></xsl:when>
                    
                    <xsl:otherwise><w:t xml:space="preserve">MUST hold <xsl:copy-of select="$plainType"/></w:t></xsl:otherwise>
                </xsl:choose>
            </w:r>
            
            <xsl:if test="//xs:complexType [@name = $localType]">
                <w:r w:rsidR="00C607DF">
                    <w:fldChar w:fldCharType="begin"/>
                </w:r>
                <w:r w:rsidR="00C607DF">
                    <w:instrText xml:space="preserve"> REF _Ref<xsl:value-of select="generate-id(//xs:complexType [@name = $localType])"/> \r \h </w:instrText>
                </w:r>
                <w:r w:rsidR="00C607DF">
                    <w:fldChar w:fldCharType="separate"/>
                </w:r>
                <w:r w:rsidR="00C607DF">
                    <w:rPr>
                        <w:rStyle w:val="Datatype"/>
                        <w:rFonts w:eastAsia="Courier New" w:cs="Courier New"/>
                    </w:rPr>
                    <w:t><xsl:value-of select="$localType"/></w:t>
                </w:r>
                <w:r w:rsidR="00C607DF">
                    <w:fldChar w:fldCharType="end"/>
                </w:r>
            </xsl:if>
            <w:r w:rsidR="00C607DF">
                <w:t>.</w:t>
            </w:r>
            
            

            <xsl:choose>
                <xsl:when test="string-length( normalize-space($doc)) &gt; 0">
                    <w:r w:rsidR="00C607DF">
                        <w:t xml:space="preserve"> </w:t>
                    </w:r>
                    <xsl:call-template name="printElementContent">
                        <xsl:with-param name="content" select="$doc"/>
                        <xsl:with-param name="elementName" select="$name"/>
                    </xsl:call-template>
                </xsl:when>
                
                <xsl:otherwise/>
            </xsl:choose>
                    
        </w:p>
        
    </xsl:template>
    
    
    <xsl:template name="printElementContent">
        <xsl:param name="content"/>
        <xsl:param name="elementName"/>

        <!--w:r w:rsidR="00E210AD">
            <w:t>~<xsl:value-of select="$content"/>~<xsl:value-of select="$elementName"/>~<xsl:value-of select="contains($content, $elementName)"/>~</w:t>
        </w:r-->
        
        <xsl:choose>
            <xsl:when test="string-length(normalize-space($content)) = 0"></xsl:when>
            
            <xsl:when test="not(contains($content, $elementName))">
                <w:r w:rsidR="00E210AD">
                    <w:t  xml:space="preserve"><xsl:value-of select="$content"/></w:t>
                </w:r>
            </xsl:when>
            
            <xsl:when test="starts-with($content, $elementName)">
                <w:r w:rsidR="00E210AD">
                    <w:rPr>
                        <w:rStyle w:val="Datatype"/>
                        <w:rFonts w:eastAsia="Courier New" w:cs="Courier New"/>
                    </w:rPr>
                    <w:t><xsl:value-of select="$elementName"/></w:t>
                </w:r>
                <xsl:call-template name="printElementContent">
                    <xsl:with-param name="content" select="substring-after($content, $elementName)"/>
                    <xsl:with-param name="elementName" select="$elementName"/>
                </xsl:call-template>
            </xsl:when>
            
            <xsl:otherwise>
                <xsl:variable name="textContent" select="substring-before($content, $elementName)"/>
                
                <w:r w:rsidR="00E210AD">
                    <w:t xml:space="preserve"><xsl:value-of select="$textContent"/></w:t>
                </w:r>
                <xsl:call-template name="printElementContent">
                    <xsl:with-param name="content" select="substring($content, string-length($textContent) + 1)"/>
                    <xsl:with-param name="elementName" select="$elementName"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:template>
    
    
    
    <xsl:template name="beautifyXMLFragment">
        <xsl:param name="indent"></xsl:param>
        
        <xsl:variable name="nsPrefix">
            <xsl:choose>
                <xsl:when test="contains(name(.), ':')"><xsl:value-of select="concat(substring-before(name(.),':'), ':')"/></xsl:when>
            </xsl:choose>
        </xsl:variable>

        <xsl:variable name="subNodes" select="node()[local-name() and not(local-name() = 'annotation')]"/>
            
        <w:p w14:paraId="663CD29A" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
            <w:pPr>
                <w:pStyle w:val="Code"/>
            </w:pPr>
            <!-- start element -->
            <w:r>
                <w:rPr>
                    <w:color w:val="31849B" w:themeColor="accent5" w:themeShade="BF"/>
                </w:rPr>
                <w:t xml:space="preserve"><xsl:value-of select="$indent"/>&lt;<xsl:value-of select="$nsPrefix"/><xsl:value-of select="local-name()"/></w:t>
            </w:r>
            <xsl:for-each select="./@*">
                <!-- attributes name -->
                <w:r>
                    <w:rPr>
                        <w:color w:val="943634" w:themeColor="accent2" w:themeShade="BF"/>
                    </w:rPr>
                    <w:t xml:space="preserve"> <xsl:value-of select="local-name()"/>="</w:t>
                </w:r>
                <!-- attributes value -->
                <w:r>
                    <w:rPr>
                        <w:color w:val="244061" w:themeColor="accent1" w:themeShade="80"/>
                    </w:rPr>
                    <w:t><xsl:value-of select="."/></w:t>
                </w:r>
                <w:r>
                    <w:rPr>
                        <w:color w:val="943634" w:themeColor="accent2" w:themeShade="BF"/>
                    </w:rPr>
                    <w:t>"</w:t>
                </w:r>
            </xsl:for-each>
            
            <!-- end element -->
            <w:r>
                <w:rPr>
                    <w:color w:val="31849B" w:themeColor="accent5" w:themeShade="BF"/>
                </w:rPr>
                <xsl:if test="not($subNodes)"><w:t>/</w:t></xsl:if>
                <w:t>&gt;</w:t>
            </w:r>
        </w:p>
        
        <xsl:if test="$subNodes">
            <xsl:for-each select="$subNodes">
                <xsl:call-template name="beautifyXMLFragment">
                    <xsl:with-param name="indent" select="concat($indent, '  ')"/>
                </xsl:call-template>
            </xsl:for-each>
            
            <w:p w14:paraId="663CD29A" w14:textId="77777777" w:rsidR="002062A5" w:rsidRDefault="002062A5" w:rsidP="002062A5">
                <w:pPr>
                    <w:pStyle w:val="Code"/>
                </w:pPr>
                <w:r>
                    <w:rPr>
                        <w:color w:val="31849B" w:themeColor="accent5" w:themeShade="BF"/>
                    </w:rPr>
                    <w:t xml:space="preserve"><xsl:value-of select="$indent"/>&lt;/<xsl:value-of select="$nsPrefix"/><xsl:value-of select="local-name()"/>&gt;</w:t>
                </w:r>
            </w:p>
        </xsl:if>
        
    </xsl:template>
    
    
    
     <!-- default matcher -->
    <xsl:template match="@* | node()">
        <xsl:copy>
            <xsl:apply-templates select="@* | node()"/>
        </xsl:copy>
    </xsl:template>
    
    
</xsl:stylesheet>